@@ -22,22 +22,22 @@ from troveclient.v1 import datastores
 from troveclient.v1 import flavors
 from troveclient.v1 import instances
 from troveclient.v1 import limits
+from troveclient.v1 import metadata
 from troveclient.v1 import root
 from troveclient.v1 import security_groups
 from troveclient.v1 import users
 
 
 class Client(object):
-    """
-    Top-level object to access the OpenStack Database API.
+    """Top-level object to access the OpenStack Database API.
 
     Create an instance with your creds::
 
-        >>> client = Client(USERNAME, PASSWORD, PROJECT_ID, AUTH_URL)
+        >> client = Client(USERNAME, PASSWORD, PROJECT_ID, AUTH_URL)
 
     Then call methods on its managers::
 
-        >>> client.instances.list()
+        >> client.instances.list()
         ...
 
     """
@@ -67,15 +67,16 @@ class Client(object):
         self.configurations = configurations.Configurations(self)
         config_parameters = configurations.ConfigurationParameters(self)
         self.configuration_parameters = config_parameters
+        self.metadata = metadata.Metadata(self)
 
-        #self.hosts = Hosts(self)
-        #self.quota = Quotas(self)
-        #self.storage = StorageInfo(self)
-        #self.management = Management(self)
-        #self.mgmt_flavor = MgmtFlavors(self)
-        #self.accounts = Accounts(self)
-        #self.diagnostics = DiagnosticsInterrogator(self)
-        #self.hwinfo = HwInfoInterrogator(self)
+        # self.hosts = Hosts(self)
+        # self.quota = Quotas(self)
+        # self.storage = StorageInfo(self)
+        # self.management = Management(self)
+        # self.mgmt_flavor = MgmtFlavors(self)
+        # self.accounts = Accounts(self)
+        # self.diagnostics = DiagnosticsInterrogator(self)
+        # self.hwinfo = HwInfoInterrogator(self)
 
         # Add in any extensions...
         if extensions:
@@ -105,8 +106,7 @@ class Client(object):
             bypass_url=bypass_url)
 
     def authenticate(self):
-        """
-        Authenticate against the server.
+        """Authenticate against the server.
 
         Normally this is called automatically when you first access the API,
         but you can call this method to force authentication right now.
