@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # Copyright 2013 Rackspace Hosting
 # All Rights Reserved.
@@ -20,31 +18,25 @@ from troveclient import base
 
 
 class Flavor(base.Resource):
-    """
-    A Flavor is an Instance type, specifying among other things, RAM size.
-    """
+    """A Flavor is an Instance type, specifying other things, like RAM size."""
 
     def __repr__(self):
         return "<Flavor: %s>" % self.name
 
 
 class Flavors(base.ManagerWithFind):
-    """
-    Manage :class:`Flavor` resources.
-    """
+    """Manage :class:`Flavor` resources."""
     resource_class = Flavor
 
     def list(self):
-        """
-        Get a list of all flavors.
+        """Get a list of all flavors.
 
         :rtype: list of :class:`Flavor`.
         """
         return self._list("/flavors", "flavors")
 
     def get(self, flavor):
-        """
-        Get a specific flavor.
+        """Get a specific flavor.
 
         :rtype: :class:`Flavor`
         """
